# Ledger

## What is Ledger

Ledger is a personal finance management app that enables users to log and track their income and expenses. Users can create entries by specifying the transaction type (income or expense), amount, category (e.g., groceries, salary, entertainment), and date. The app includes a summary screen for a quick overview of finances and a detailed transaction list for reviewing all logged entries. Users can edit or delete entries as needed, ensuring accurate record-keeping. FinanceFlow helps users stay on top of their budget with a clear and organized interface.

## The Team

[Xaver Drabik](https://www.linkedin.com/in/xaverdrabik/) & [Florian Kraushofer](https://www.linkedin.com/in/florian-kraushofer-16892b26a/)

## App Concept

### Use Case
Primary Use Case:
- Tracking and Managing Personal Finances
- Viewing Financial Summaries
- Logging Transactions
- Organizing Finances by Categories
- Financial Planning
- Monitoring Budgets

### Target Users
People who want a simple and effective way to manage their personal finances.
People who want to stay organized by tracking their income and expenses, categorizing transactions, and gaining insights into their financial habits.

Like:
- Freelancers
- Students
- Budget-Conscious Individuals
- Small Business Owners

### Mockups

![Mockup](mockup.png)
![Userflow](UserFlow.png)

## Usability Testing Plan
### Experimental Questions & Variables
1. Question: Did you find the app easy to use?
	- IV: App navigation design (e.g., layout, menu structure, or usability features).
	- DV: User-reported issues or difficulties while navigating.
	- Methods: SEQ Question

2. Question: Does the user find Categories useful?
	- IV: Presence or design of the Categories feature.
	- DV: User perception of usefulness (e.g., measured via survey or rating).
	- Method: Likert scale How useful was it?
3. Question: Does the user find Categories?
	- IV: Visibility or accessibility of the Categories feature.
	- DV: User success in locating or using Categories.
	- Method: Task Completion Testing

4. Question: Does the icon selection affect user satisfaction?
	- IV: Icon design or selection (e.g., different icon styles or clarity).
	- DV: User satisfaction (e.g., measured via survey or rating).
	- Method: Open Question

5. Question: How long does it take for a user to add a Category?
	- IV: Process or interface for adding a Category (e.g., number of steps, clarity of instructions).
	- DV: Time taken to complete the task.
	- Method: Time till completion

6. Question: How long does it take for a user to add a Transaction?
	- IV: Process or interface for adding a Transaction (e.g., simplicity, number of fields).
	- DV: Time taken to complete the task.
	- Method: Time till completion

### Heuristic Evaluation 
Based off of Nielsen’s 10 Heuristics. Done by both team members based on the Mockup. Results were implemented in the android application.
1. Visibility of System Status
	- Issue: Users may not be immediately aware of changes to their balance after adding or editing a transaction, as there is no clear feedback.
	- Recommendations: Implement a visual or auditory feedback system (e.g., a confirmation message or animation or redirect to the Balance overview) to inform users when their balance updates.

2. Match Between System and the Real World
	- Issues: None
	- Recommendations: None

3. User Control and Freedom
	- Issues: Users might want to create their own categories rather than use the predefined ones.
	- Recommendations: Introduce a feature to add and delete your own categories.
4. Consistency and Standards
	- Issues: The "Your Balance" and the name of the transaction do not share the same font
	- Recommendations: Standardize all texts to use the same font, and color scheme for a cohesive user experience.

5. Error Prevention
	- Issues: Users might enter invalid data, such as symbols as the amount, without receiving a warning, leading to potential errors.
	- Recommendations: Add validation checks and warnings to prevent users from entering incorrect data, ensuring errors are caught before submission.

6. Recognition Rather Than Recall
	- Issues: Users may need to remember details about past transactions, such as categories or dates, which could increase cognitive load.
	- Recommendations: Display a detailed transaction history with categories and dates visible at all times, reducing the need for users to recall information.

7. Flexibility and Efficiency of Use
	- Issues: Users may find it time-consuming to navigate through multiple screens or steps to perform common tasks, such as adding or editing transactions.
	- Recommendations: Ensure that all frequently used actions, like adding or deleting transactions, can be completed in as few steps as possible, with clear and accessible buttons for quick access.
8. Aesthetic and Minimalist Design
	- Issues: The interface might include too many visual elements or colors, which could distract users from focusing on their primary tasks, such as managing transactions or checking their balance.
	- Recommendations: Ensure that the design remains clean and focused by using a limited color palette and removing any unnecessary decorative elements, keeping the interface visually simple and task-oriented.

9. Help Users Recognize, Diagnose, and Recover from Errors
	- Issues: Error messages may not clearly explain what went wrong or how to fix it, leaving users confused.
	- Recommendations: Provide detailed error messages in plain language, including actionable steps to resolve the issue.

10. Help and Documentation
	- Issues: Help and Documentation may be important and nice to have but out of scope for this version of the design. 
	- Recommendations: For now, focus on maintaining the clarity and simplicity of the current help documentation. If these advanced features are considered in future updates, ensure that corresponding help resources are developed to support them.

## Results

![test](test.jpeg)

### Participant Demographics
- **Number of Test Subjects:** 5
- **Demographics:** Not specified in the data.

### Quantitative Evaluation

#### Task Completion Time

##### Adding a Category:
| Participant | Time (seconds) |
|-------------|----------------|
| 1           | 18             |
| 2           | 69             |
| 3           | 40             |
| 4           | 18             |
| 5           | 15             |

**Average Time:** 32 seconds

##### Adding a Transaction:

| Participant | Time (seconds) |
|-------------|----------------|
| 1           | 18             |
| 2           | 11             |
| 3           | 60             |
| 4           | 43             |
| 5           | 30             |

**Average Time:** 32.4 seconds

#### User Satisfaction Scores

##### Ease of Use (Scale: 1-7):

| Participant | Score |
|-------------|-------|
| 1           | 7     |
| 2           | 5     |
| 3           | 7     |
| 4           | 7     |
| 5           | 6     |

**Average Score:** 6.4

##### Usefulness of Categories (Scale: 1-5):

| Participant | Score |
|-------------|-------|
| 1           | 3     |
| 2           | 4     |
| 3           | 4     |
| 4           | 5     |
| 5           | 5     |

**Average Score:** 4.2

#### Task Success Rate

**Finding Categories:**
  - 4 out of 5 participants (80%) found the categories.
  - 1 participant did not find the categories.

**Icon Selection Satisfaction:**
  - 4 out of 5 participants (80%) were satisfied with the icon selection.
  - 1 participant noted that "Pets missing" in the icon selection.

### Charts

- **Bar Chart:** Task completion times for adding categories and transactions.
- **Pie Chart:** Percentage of participants who found categories and were satisfied with icon selection.

## Qualitative Feedback

**Positive Feedback:**
- "The app is easy to use." (Participant 1, 3, 4)
- "Categories are useful for organizing transactions." (Participant 4, 5)

**Negative Feedback:**
- "I could not find the categories initially." (Participant 2)
- "The icon selection is missing a Pets category." (Participant 4)

**Suggestions for Improvement:**
- "Add more icons, especially for Pets." (Participant 4)
- "Improve the visibility of categories in the app." (Participant 2)

## Updates Made to the App

Based on the feedback, the following updates were made:

- **Improved Visibility of System Status:** Added Headings for _Category_ and _Transaction_ Screens.
- **Improved Category Visibility:** The categories section was redesigned to make it more intuitive and easier to find.